from distutils.core import setup


setup(
  name='ybc_config',
  packages=['ybc_config'],
  package_data={'ybc_config': ['*.py', '*.yaml']},
  version='1.0.0',
  description='Environment config',
  long_description='Environment config',
  author='lijz01',
  author_email='lijz01@fenbi.com',
  keywords=['python', 'config'],
  license='MIT',
  install_requires=['yaml']
)
